const DailyRotateFile = require("winston-daily-rotate-file");
const fs = require("fs");

const rotate = require("./rotate.js");

module.exports = function({
	name,
	level,
	logs_path,
	format,
	date_pattern,
	max_size,
	max_files,
	on_limit
}) {
	// Create the directory if it does not exist yet.
	if (!fs.existsSync(logs_path)) {
		fs.mkdirSync(logs_path);
	}

	const log_transport = new DailyRotateFile({
		format: format,
		level: level,
		filename: `${name}.log.%DATE%`,
		dirname: logs_path,
		datePattern: date_pattern,
		maxsize: max_size,
		maxFiles: max_files
	});

	log_transport.on("rotate", (old_file_path, new_file_path) => {
		rotate(old_file_path, new_file_path, on_limit);
	});

	return log_transport;
};
